==> nextcloud-app-spreed-1%3A12.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/lib/Events/SignalingRoomPropertiesEvent.php <==
<?php

declare(strict_types=1);
/**
 * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\Talk\Events;

use OCA\Talk\Room;

class SignalingRoomPropertiesEvent extends RoomEvent {

	/** @var string|null */
	protected $userId;
	/** @var array */
	protected $properties;

	public function __construct(Room $room, ?string $userId, array $properties) {
		parent::__construct($room);
		$this->userId = $userId;
		$this->properties = $properties;
	}

	public function getUserId(): ?string {
		return $this->userId;
	}

	public function getProperties(): array {
		return $this->properties;
	}

	public function setProperty(string $property, $data): void {
		$this->properties[$property] = $data;
	}

	public function unsetProperty(string $property): void {
		unset($this->properties[$property]);
	}
}

==> nextcloud-app-spreed-1%3A16.0.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/lib/Events/SignalingRoomPropertiesEvent.php <==
<?php

declare(strict_types=1);
/**
 * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\Talk\Events;

use OCA\Talk\Room;

class SignalingRoomPropertiesEvent extends RoomEvent {
	protected ?string $userId;
	protected array $properties;

	public function __construct(
		Room $room,
		?string $userId,
		array $properties,
	) {
		parent::__construct($room);
		$this->userId = $userId;
		$this->properties = $properties;
	}

	public function getUserId(): ?string {
		return $this->userId;
	}

	public function getProperties(): array {
		return $this->properties;
	}

	public function setProperty(string $property, $data): void {
		$this->properties[$property] = $data;
	}

	public function unsetProperty(string $property): void {
		unset($this->properties[$property]);
	}
}
